@@ -32,9 +32,9 @@ class Parameters:
         8: Unknown("ID_SU_FrkdAl"),
         9: Unknown("ID_Einst_HReg_akt"),
         10: Unknown("ID_Einst_HzHwMAt_akt"),
-        11: Unknown("ID_Einst_HzHwHKE_akt"),
-        12: Unknown("ID_Einst_HzHKRANH_akt"),
-        13: Unknown("ID_Einst_HzHKRABS_akt"),
+        11: Celsius("ID_Einst_HzHwHKE_akt"),
+        12: Celsius("ID_Einst_HzHKRANH_akt"),
+        13: Celsius("ID_Einst_HzHKRABS_akt"),
         14: Unknown("ID_Einst_HzMK1E_akt"),
         15: Unknown("ID_Einst_HzMK1ANH_akt"),
         16: Unknown("ID_Einst_HzMK1ABS_akt"),
@@ -721,7 +721,7 @@ class Parameters:
         697: Unknown("ID_Einst_Zirk_Ein_akt"),
         698: Unknown("ID_Einst_Zirk_Aus_akt"),
         699: Unknown("ID_Einst_Heizgrenze"),
-        700: Unknown("ID_Einst_Heizgrenze_Temp"),
+        700: Celsius("ID_Einst_Heizgrenze_Temp"),
         701: Unknown("ID_VariablenIBNgespeichert"),
         702: Unknown("ID_SchonIBNAssistant"),
         703: Unknown("ID_Heizgrenze_0"),
